#!/usr/bin/perl -w
#
###################################################
#Version: 1.0
#Author: Daniel Koffler
#
# NXE Client 1.0 for the Nagios XML Engine version 1.x
#
# This application provides several methods of reporting data from Nagios in XML format
# as well as transforming that XML via XSLT. An XML based command interpreter is also included.
#
# This application can be accessed via XML-RPC or HTTP Get when installed as an Apache
# or IIS (or any other Perl capable Web Server) CGI. Alternatively, you can run this
# application from the command line.
#
# Please see the README file that came with this application for more details.
#
# Nagios is a trademark of Ethan Galstad.
# For more information see http://www.nagios.org or http://www.xmlexperts.org/nxe
#
# Copyright (C) 2003 Daniel Koffler
#
#This library is free software; you can redistribute it and/or
#modify it under the terms of the GNU Lesser General Public
#License as published by the Free Software Foundation; either
#version 2.1 of the License, or (at your option) any later version.
#
#This library is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#Lesser General Public License for more details.
#
#You should have received a copy of the GNU Lesser General Public
#License along with this library; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
####################################################
# Revision History:
# Revision 1.0 June 2003 Daniel Koffler
####################################################

use strict;
use Getopt::Std;
use Frontier::Client;
use URI;
use URI::Heuristic;

sub bail {
    print @_;
    print "\n\n";
    print <<"ENDMSG";

*************************************************************************
USAGE:
    nxe_client [-p proxyhost] URL COMMAND PARAM1 [PARAM2 PARAM3... PARAMX]
    
    proxyhost: Optional argument specifying a HTTP Proxy to use for requests to the
		nxe XML-RPC server CGI.
		
    URL:	The full URL to the nxe XML-RPC server cgi.
    
    COMMAND:	The command to execute at the remote Nagios system. Options are
		"status", "transform", "cmd", "transform_cmd". See nxe XML-RPC
		server CGI documentation for details.
    
    PARAM1-X:	Parameters in the order required by nxe XML-RPC server CGI command.
    
Example:

nxe_client -p http://proxy.mydomain.com http://nagios.mydomain.com transform xsl1 status

Copyright (C) 2003 Daniel Koffler.
*************************************************************************

ENDMSG
die @_;
}

our($opt_p, $opt_h);
getopts("hp:");
bail if (defined($opt_h));

my $server = URI::Heuristic::uf_urlstr(shift(@ARGV)) || bail "You must specify a valid URL for the NXE Server\n\n";
my $proxy = URI::Heuristic::uf_urlstr($opt_p) if (defined ($opt_p));
my $client = Frontier::Client->new(url=> "$server",
				    proxy=> "$opt_p") || bail "Can't create Frontier RPC-XML client\n\n";

my $response = $client->call(@ARGV) || bail "Error executing command $ARGV";
print $response;
exit (0)
