<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="html" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" />
    <xsl:template match="/NXE_RESULT">
    <xsl:variable name="proc_num" select="count(NAG_PROC)"/>
        <html>
<xsl:comment> Copyright (c)  2003  Daniel Koffler.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation;with the Invariant Sections being this comment text including all licensing provisions. A copy of the license is available at http://www.gnu.org/copyleft/fdl.html in the section entitled "GNU Free Documentation License".Nagios is a copyright of Ethan Galstad.
See http://www.nagios.org for more information.
</xsl:comment>

            <head />
            <body>
            <center>
            <h1><xsl:value-of select="@NAME"/></h1>
            <h2><xsl:value-of select="$proc_num"/> location<xsl:if test="$proc_num > 1">s</xsl:if>
            from <xsl:value-of select="@SOURCE"/></h2>
            </center>
            <table border="1" width="100%">
            <!-- Header Row -->
            <tr>
            <td><b>Process Host</b></td>
            <td><b>Hosts Up</b></td>
            <td><b>Hosts Down or <br/>Unreachable</b></td>
            <td><b>Services OK</b></td>
            <td><b>Services Warning</b></td>
            <td><b>Services Critical <br/>or Unkown</b></td>
            </tr>
            <xsl:apply-templates select="NAG_PROC" mode="summary"></xsl:apply-templates>
            </table>
            
            <xsl:apply-templates select="NAG_PROC" mode="full"></xsl:apply-templates>

            </body>
            </html>
            </xsl:template>
            

<xsl:template match="NAG_PROC" mode="summary">
            <xsl:variable name="host_name" select="@HOST_NAME"/>
            <xsl:variable name="host_down_count" select="count(HOST[@HST_STATUS='DOWN'] | HOST[@HST_STATUS='UNREACHABLE'])"/>
            <xsl:variable name="svc_warn_count" select="count(SERVICE[@SVC_STATUS='WARNING'])"/>
            <xsl:variable name="svc_crit_count" select="count(SERVICE[@SVC_STATUS='CRITICAL'] | SERVICE[@SVC_STATUS='UNKOWN'])"/>
            <tr>
            <td><a><xsl:attribute name="href">#<xsl:value-of select="$host_name"/></xsl:attribute><xsl:value-of select="$host_name"/></a></td>
            <td><xsl:value-of select="count(HOST[@HST_STATUS='UP'])"/></td>

            <td>
            <xsl:if test="$host_down_count > 0">
            <xsl:attribute name="bgcolor">red</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="$host_down_count"/>
            </td>
            
            <td><xsl:value-of select="count(SERVICE[@SVC_STATUS='OK'])"/></td>
            <td>
            <xsl:if test="$svc_warn_count > 0">
            <xsl:attribute name="bgcolor">yellow</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="$svc_warn_count"/>
            </td>

            <td>
            <xsl:if test="$svc_crit_count > 0">
            <xsl:attribute name="bgcolor">red</xsl:attribute>
            </xsl:if>
            <xsl:value-of select="$svc_crit_count"/>
            </td></tr>
</xsl:template>
            
            
<xsl:template match="NAG_PROC" mode="full">
            <xsl:variable name="host_name" select="@HOST_NAME"/>
            <xsl:variable name="hosts" select="HOST"/>
            <xsl:variable name="service" select="SERVICE"/>
            <h1><center>
            <a>
            <xsl:attribute name="name">#<xsl:value-of select="$host_name"/></xsl:attribute>
            <xsl:value-of select="$host_name"/> Results Table:
            </a>
            </center></h1>

            <table border="1">
            <tr>
            <td><b>Host</b></td>
            <td><b>Service</b></td>
            <td><b>Status</b></td>
            <td><b>Last Check</b></td>
            <td><b>Check Result</b></td>
            
            </tr>

            <xsl:for-each select="HOST">
            <xsl:variable name="svc_nodes" select="following-sibling::* | preceding-sibling::*"></xsl:variable>
            <xsl:variable name="host_name2" select="@HOSTNAME"/>
            <xsl:variable name="host_stat" select="@HST_STATUS"/>

            <tr>
            <td colspan="2"> <b><xsl:value-of select="$host_name2"/></b></td>
            <td>
            <xsl:choose>
                             <xsl:when test='$host_stat="DOWN"'>
                             <xsl:attribute name="bgcolor">red</xsl:attribute>
                             </xsl:when>
                             <xsl:when test='$host_stat="UNREACHABLE"'>
                             <xsl:attribute name="bgcolor">red</xsl:attribute>
                             </xsl:when>
                             <xsl:otherwise>
                             <xsl:attribute name="bgcolor">green</xsl:attribute>
                             </xsl:otherwise>
            </xsl:choose>
            <b><xsl:value-of select="$host_stat"/></b></td>
            <td><xsl:value-of select="@LAST_CHECK"/></td>
            <td><xsl:value-of select="@HST_PLUG_OUTPUT"/></td>
            
            </tr>
            
                 <xsl:for-each select="$svc_nodes[@HOSTNAME=$host_name2]">
                 <xsl:variable name="svc_status" select="@SVC_STATUS"></xsl:variable>
                 <tr>
                 
                 <td></td>
                 <td><xsl:value-of select="@SVC_DESC"/></td>
                 <td>
                 <xsl:choose>
                             <xsl:when test='$svc_status="CRITICAL"'>
                             <xsl:attribute name="bgcolor">red</xsl:attribute>
                             </xsl:when>
                             <xsl:when test='$svc_status="UNKNOWN"'>
                             <xsl:attribute name="bgcolor">red</xsl:attribute>
                             </xsl:when>
                             <xsl:when test='$svc_status="WARNING"'>
                             <xsl:attribute name="bgcolor">yellow</xsl:attribute>
                             </xsl:when>
                             <xsl:otherwise>
                             <xsl:attribute name="bgcolor">green</xsl:attribute>
                             </xsl:otherwise>
                 </xsl:choose>

                 <b><xsl:value-of select="$svc_status"/></b></td>
                 <td><xsl:value-of select="@LAST_CHECK"/></td>
                 <td><xsl:value-of select="@SVC_PLUG_OUTPUT"/></td>
                 

                 </tr>
                 </xsl:for-each>
            
            </xsl:for-each>
            </table>
</xsl:template>
</xsl:stylesheet>
            
            
